# ceilometer-instance-poller crontab definition

*/15 * * * * ceilometer [ -x /usr/bin/ceilometer-instance-poller ] && flock -w 3600 /var/run/lock/ceilometer-instance-poller -c 'sudo /usr/bin/ceilometer-instance-poller --config-file /etc/ceilometer-instance-poller/ceilometer-instance-poller.conf --do-not-print'
